@@ -1,12 +1,14 @@
 #!/usr/bin/env seed
 
-Seed.import_namespace("Canvas");
-Seed.import_namespace("Clutter", "0.8");
-Seed.import_namespace("ClutterCairo", "0.8");
+Canvas = imports.canvas;
+imports.gi.versions.Clutter = "0.9"
 
-Clutter.init(null, null);
+Clutter = imports.gi.Clutter;
 
-c = new ClutterCairo.ClutterCairo.c_new(100, 100);
+Clutter.init(Seed.argv);
+
+c = new Clutter.CairoTexture();
+c.set_surface_size(100, 100);
 cr = c.create();
 
 ctx = new Canvas.CairoCanvas(cr);
@@ -22,8 +24,8 @@ c.x = c.y = 100;
 
 ctx.destroy();
 
-s = new Clutter.Stage();
-s.signal.hide.connect(function () { Clutter.main_quit(); });
+s = Clutter.Stage.get_default();
+s.signal.hide.connect(Clutter.main_quit);
 
 s.add_actor(c);
 
