@@ -1,7 +1,7 @@
-#!/usr/local/bin/seed
+#!/usr/bin/env seed
 xml = imports.libxml;
 doc = xml.parseFile("./sample.xml");
 ctx = doc.xpathNewContext();
 
 results = ctx.xpathEval("//story/body/headline");
-Seed.print("Headline: " + results.value[0].content);
+print("Headline: " + results.value[0].content);
