@@ -1,16 +1,16 @@
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
- * Seed is free software: you can redistribute it and/or modify 
+ * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version. 
- * Seed is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- * GNU Lesser General Public License for more details. 
- * You should have received a copy of the GNU Lesser General Public License 
- * along with Seed.  If not, see <http://www.gnu.org/licenses/>. 
+ * the License, or (at your option) any later version.
+ * Seed is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
  * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
  */
@@ -27,6 +27,16 @@ JSObjectRef seed_gtype_constructor;
 GQuark qgetter;
 GQuark qsetter;
 
+GQuark qiinit;
+GQuark qcinit;
+
+typedef struct _SeedGClassPrivates {
+  JSObjectRef constructor;
+  JSObjectRef func;
+
+  JSObjectRef definition;
+} SeedGClassPrivates;
+
 static JSValueRef
 seed_property_method_invoked (JSContextRef ctx,
 			      JSObjectRef function,
@@ -42,11 +52,9 @@ seed_property_method_invoked (JSContextRef ctx,
 
   if (argumentCount != 1)
     {
-      gchar *mes =
-	g_strdup_printf ("Property installation expected 1 argument"
-			 " got %Zd \n", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "Property installation expected 1 argument"
+			   " got %zd \n", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
@@ -95,10 +103,9 @@ seed_gsignal_method_invoked (JSContextRef ctx,
   /* Sanity check */
   if (argumentCount != 1)
     {
-      gchar *mes = g_strdup_printf ("Signal constructor expected 1 argument"
-				    " got %Zd \n", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "Signal constructor expected 1 argument"
+			   " got %zd \n", argumentCount);
       return (JSObjectRef) JSValueMakeNull (ctx);
     }
   if (JSValueIsNull (ctx, arguments[0])
@@ -193,7 +200,7 @@ seed_gtype_builtin_set_property (GObject * object,
   JSContextRef ctx = JSGlobalContextCreateInGroup (context_group, 0);
   gchar *name = g_strjoin (NULL, "_", spec->name, NULL);
   JSObjectRef jsobj = (JSObjectRef) seed_value_from_object (ctx, object, 0);
-  
+
   seed_prepare_global_context (ctx);
 
   seed_object_set_property (ctx,
@@ -256,16 +263,15 @@ seed_gtype_get_property (GObject * object,
 static GIBaseInfo *
 seed_get_class_info_for_type (GType type)
 {
-  GType parent;
   GIBaseInfo *object_info;
-  
-  while (type = g_type_parent (type))
+
+  while ((type = g_type_parent (type)))
     {
       object_info = g_irepository_find_by_gtype (NULL, type);
       if (object_info)
 	{
 	  return
-	    (GIBaseInfo *)g_object_info_get_class_struct 
+	    (GIBaseInfo *)g_object_info_get_class_struct
 	                  ((GIObjectInfo *)object_info);
 	}
       g_base_info_unref (object_info);
@@ -273,7 +279,7 @@ seed_get_class_info_for_type (GType type)
   return NULL;
 }
 
-static void 
+static void
 seed_attach_methods_to_class_object (JSContextRef ctx,
 				     JSObjectRef object,
 				     JSValueRef *exception)
@@ -284,140 +290,196 @@ seed_attach_methods_to_class_object (JSContextRef ctx,
 			&seed_gsignal_method_invoked, object);
 }
 
+static GObject *
+seed_gtype_construct (GType type,
+		      guint n_construct_params,
+		      GObjectConstructParam *construct_params)
+{
+  JSContextRef ctx;
+  JSObjectRef func, this_object;
+  JSValueRef exception = NULL, args[1];
+  GObject *object;
+  GType parent;
+  GObjectClass *parent_class;
 
+  parent = g_type_parent (type);
+  parent_class = g_type_class_ref (parent);
+
+  object = parent_class->constructor (type, n_construct_params, construct_params);
+
+  g_type_class_unref (parent_class);
+
+  func = g_type_get_qdata (type, qiinit);
+  if (func)
+    {
+      ctx = JSGlobalContextCreateInGroup (context_group, 0);
+      seed_prepare_global_context (ctx);
+
+      SEED_NOTE (GTYPE, "Handling constructor for: %p with type: %s",
+		 object, g_type_name (type));
+      this_object = (JSObjectRef) seed_value_from_object (ctx, object, NULL);
+      args[0] = this_object;
+
+      JSObjectCallAsFunction (ctx, func, this_object, 1, args, &exception);
+      if (exception)
+	{
+	  gchar *mes = seed_exception_to_string (ctx, exception);
+	  g_warning ("Exception in instance construction. %s \n", mes);
+	  g_free (mes);
+	}
+      JSGlobalContextRelease ((JSGlobalContextRef) ctx);
+    }
+
+  return object;
+}
 
 static void
-seed_handle_class_init_closure (ffi_cif * cif,
-				void *result, 
-				void **args, 
-				void *userdata)
+seed_gtype_install_signals (JSContextRef ctx,
+			    JSObjectRef definition,
+			    GType type)
 {
-  JSObjectRef function = (JSObjectRef) userdata;
+  JSObjectRef signals;
+  JSValueRef jslength;
+  guint i, length;
+
+  signals = (JSObjectRef) seed_object_get_property (ctx, definition, "signals");
+  if (JSValueIsNull(ctx, signals) || !JSValueIsObject (ctx, signals))
+    return;
+
+  jslength = seed_object_get_property (ctx, signals, "length");
+  if (JSValueIsNull (ctx, jslength))
+    return;
+
+  length = seed_value_to_uint (ctx, jslength, NULL);
+  for (i = 0; i < length; i++)
+    {
+      GType return_type;
+      GType *param_types = NULL;
+      guint n_params = 0;
+      GSignalFlags flags;
+      JSValueRef jsname, jsflags, jsreturn_type, jsparams;
+      gchar *name;
+      JSObjectRef signal_def = (JSObjectRef)JSObjectGetPropertyAtIndex (ctx,
+									(JSObjectRef) signals,
+									i,
+									NULL);
+
+      if (JSValueIsNull (ctx, signal_def) || !JSValueIsObject(ctx, signal_def))
+	continue;
+
+      // TODO: Error checking
+      jsname = seed_object_get_property (ctx, signal_def, "name");
+      name = seed_value_to_string (ctx, jsname, NULL);
+
+      SEED_NOTE(GTYPE, "Installing signal with name: %s on type: %s",
+		name, g_type_name (type));
+
+      jsflags = seed_object_get_property (ctx, (JSObjectRef) signal_def, "flags");
+      if (JSValueIsNull (ctx, jsflags) || !JSValueIsNumber (ctx, jsflags))
+	flags = G_SIGNAL_RUN_LAST;
+      else
+	flags = seed_value_to_long (ctx, jsflags, NULL);
+
+      jsreturn_type = seed_object_get_property (ctx, signal_def, "return_type");
+      if (JSValueIsNull (ctx, jsreturn_type) || !JSValueIsNumber (ctx, jsreturn_type))
+	return_type = G_TYPE_NONE;
+      else
+	return_type = seed_value_to_long (ctx, jsreturn_type, NULL);
+
+      jsparams = seed_object_get_property (ctx, signal_def, "parameters");
+
+      if (!JSValueIsNull (ctx, jsparams) && JSValueIsObject (ctx, jsparams))
+	{
+	  n_params = seed_value_to_int (ctx, seed_object_get_property (ctx, (JSObjectRef) jsparams, "length"), NULL);
+	  if (n_params > 0)
+	    {
+	      guint i;
+
+	      param_types = g_alloca (sizeof (GType)*n_params);
+	      for (i = 0; i < n_params; i++)
+		{
+		  JSValueRef ptype = JSObjectGetPropertyAtIndex (ctx,
+								 (JSObjectRef)
+								 jsparams,
+								 i,
+								 NULL);
+		  param_types[i] = (GType) seed_value_to_long (ctx, ptype, NULL);
+		}
+	    }
+	}
+
+      g_signal_newv (name, type,
+		     flags, 0, 0, 0,
+		     gi_cclosure_marshal_generic,
+		     return_type, n_params, param_types);
+      g_free (name);
+
+    }
+
+}
+
+static void
+seed_gtype_class_init (gpointer g_class,
+		       gpointer class_data)
+{
+  SeedGClassPrivates *priv;
+  GIBaseInfo *class_info;
+  JSContextRef ctx;
   JSValueRef jsargs[2];
   GType type;
   JSValueRef exception = 0;
-  JSContextRef ctx = JSGlobalContextCreateInGroup (context_group,
-						   0);
-  GObjectClass *klass = *(GObjectClass **) args[0];
-  GIBaseInfo *class_info;
+
+  priv = (SeedGClassPrivates *)class_data;
+
+  ((GObjectClass *)g_class)->get_property = seed_gtype_get_property;
+  ((GObjectClass *)g_class)->set_property = seed_gtype_set_property;
+  ((GObjectClass *)g_class)->constructor = seed_gtype_construct;
+
+  ctx = JSGlobalContextCreateInGroup (context_group, 0);
+
+  type = (GType) JSObjectGetPrivate (priv->constructor);
+  seed_gtype_install_signals (ctx, priv->definition, type);
+
+  if (!priv->func)
+    {
+      JSGlobalContextRelease ((JSGlobalContextRef) ctx);
+      return;
+    }
+
 
   seed_prepare_global_context (ctx);
 
-  klass->get_property = seed_gtype_get_property;
-  klass->set_property = seed_gtype_set_property;
 
-  type = (GType) JSObjectGetPrivate (*(JSObjectRef *) args[1]);
-  
   class_info = seed_get_class_info_for_type (type);
-  
-  jsargs[0] = seed_make_struct (ctx, *(gpointer *) args[0], class_info);
+
+  jsargs[0] = seed_make_struct (ctx, g_class, class_info);
   jsargs[1] = seed_gobject_get_prototype_for_gtype (type);
-  
-  seed_attach_methods_to_class_object (ctx, (JSObjectRef)jsargs[0], 
-				       &exception);
-  
+
+  seed_attach_methods_to_class_object (ctx, (JSObjectRef) jsargs[0], &exception);
+
   g_base_info_unref ((GIBaseInfo *) class_info);
-  
-  SEED_NOTE (GTYPE, "Marshalling class init closure for type: %s",
+
+  SEED_NOTE (GTYPE, "Marshalling class init for type: %s",
 	     g_type_name (type));
 
-  // TODO: 
-  // Should probably have a custom type for class, and have it auto convert.
   seed_object_set_property (ctx, (JSObjectRef) jsargs[0],
 			    "type", seed_value_from_int (ctx, type, 0));
   seed_object_set_property (ctx, (JSObjectRef) jsargs[0],
 			    "property_count", seed_value_from_int (ctx, 1,
 								   0));
 
-  JSObjectCallAsFunction (ctx, function, 0, 2, jsargs, &exception);
+  JSObjectCallAsFunction (ctx, priv->func, 0, 2, jsargs, &exception);
   if (exception)
     {
       gchar *mes = seed_exception_to_string (ctx, exception);
       g_warning ("Exception in class init closure. %s \n", mes);
+      g_free (mes);
     }
 
   JSGlobalContextRelease ((JSGlobalContextRef) ctx);
 }
 
-static void
-seed_handle_instance_init_closure (ffi_cif * cif,
-				   void *result, void **args, void *userdata)
-{
-  JSObjectRef function = (JSObjectRef) userdata;
-  JSValueRef jsargs;
-  JSValueRef exception = 0;
-  JSObjectRef this_object;
 
-  JSContextRef ctx = JSGlobalContextCreateInGroup (context_group, 0);
-
-  seed_prepare_global_context (ctx);
-
-  jsargs = seed_make_pointer (ctx, *(gpointer *) args[1]);
-  this_object =
-    (JSObjectRef) seed_value_from_object (ctx, *(GObject **) args[0], 0);
-
-  SEED_NOTE (GTYPE, "Handling instance init closure for: %p with type: %s",
-	     *(GObject **) args[0],
-	     g_type_name (G_OBJECT_TYPE (*(GObject **) args[0])));
-
-  JSObjectCallAsFunction (ctx, function, this_object, 1, &jsargs, &exception);
-  if (exception)
-    {
-      gchar *mes = seed_exception_to_string (ctx, exception);
-      g_warning ("Exception in instance init closure. %s \n", mes);
-    }
-
-  JSGlobalContextRelease ((JSGlobalContextRef) ctx);
-}
-
-static ffi_closure *
-seed_make_class_init_closure (JSObjectRef function)
-{
-  ffi_cif *cif;
-  ffi_closure *closure;
-  ffi_type **arg_types;
-
-  // Might need to protect function.
-
-  cif = g_new0 (ffi_cif, 1);
-  arg_types = g_new0 (ffi_type *, 3);
-
-  arg_types[0] = &ffi_type_pointer;
-  arg_types[1] = &ffi_type_uint;
-  arg_types[2] = 0;
-
-  closure = mmap (0, sizeof (ffi_closure), PROT_READ | PROT_WRITE |
-		  PROT_EXEC, MAP_ANON | MAP_PRIVATE, -1, 0);
-
-  ffi_prep_cif (cif, FFI_DEFAULT_ABI, 2, &ffi_type_void, arg_types);
-  ffi_prep_closure (closure, cif, seed_handle_class_init_closure, function);
-  return closure;
-}
-
-static ffi_closure *
-seed_make_instance_init_closure (JSObjectRef function)
-{
-  ffi_cif *cif;
-  ffi_closure *closure;
-  ffi_type **arg_types;
-
-  // Might need to protect function.
-
-  cif = g_new0 (ffi_cif, 1);
-  arg_types = g_new0 (ffi_type *, 3);
-
-  arg_types[0] = &ffi_type_pointer;
-  arg_types[1] = &ffi_type_pointer;
-  arg_types[2] = 0;
-
-  closure = mmap (0, sizeof (ffi_closure), PROT_READ | PROT_WRITE |
-		  PROT_EXEC, MAP_ANON | MAP_PRIVATE, -1, 0);
-
-  ffi_prep_cif (cif, FFI_DEFAULT_ABI, 2, &ffi_type_void, arg_types);
-  ffi_prep_closure (closure, cif, seed_handle_instance_init_closure,
-		    function);
-  return closure;
-}
 
 static JSObjectRef
 seed_gtype_constructor_invoked (JSContextRef ctx,
@@ -440,18 +502,15 @@ seed_gtype_constructor_invoked (JSContextRef ctx,
     0,
     NULL
   };
-  ffi_closure *init_closure = 0;
-  ffi_closure *instance_init_closure = 0;
   GTypeQuery query;
   JSObjectRef constructor_ref;
+  SeedGClassPrivates *priv;
 
   if (argumentCount != 1)
     {
-      gchar *mes =
-	g_strdup_printf ("GType constructor expected 1 "
-			 "argument, got %Zd \n", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "GType constructor expected 1 "
+			   "argument, got %zd \n", argumentCount);
       return (JSObjectRef) JSValueMakeNull (ctx);
     }
   if (!JSValueIsObject (ctx, arguments[0]))
@@ -479,21 +538,7 @@ seed_gtype_constructor_invoked (JSContextRef ctx,
 
       return (JSObjectRef) JSValueMakeNull (ctx);
     }
-  if (!JSValueIsNull (ctx, class_init) &&
-      JSValueIsObject (ctx, class_init) &&
-      JSObjectIsFunction (ctx, (JSObjectRef) class_init))
-    {
-      init_closure = seed_make_class_init_closure ((JSObjectRef) class_init);
-      JSValueProtect (ctx, class_init);
-    }
-  if (!JSValueIsNull (ctx, instance_init) &&
-      JSValueIsObject (ctx, instance_init) &&
-      JSObjectIsFunction (ctx, (JSObjectRef) instance_init))
-    {
-      instance_init_closure =
-	seed_make_instance_init_closure ((JSObjectRef) instance_init);
-      JSValueProtect (ctx, instance_init);
-    }
+
 
   parent_type = (GType) seed_value_to_int (ctx, parent_ref, exception);
 
@@ -503,14 +548,29 @@ seed_gtype_constructor_invoked (JSContextRef ctx,
   g_type_query (parent_type, &query);
   type_info.class_size = query.class_size;
   type_info.instance_size = query.instance_size;
-  type_info.class_init = (GClassInitFunc) init_closure;
-  type_info.instance_init = (GInstanceInitFunc) instance_init_closure;
+  type_info.class_init = seed_gtype_class_init;
+
+  priv = g_slice_alloc (sizeof (SeedGClassPrivates));
+
+  if (!JSValueIsNull (ctx, class_init) &&
+      JSValueIsObject (ctx, class_init) &&
+      JSObjectIsFunction (ctx, (JSObjectRef) class_init))
+    {
+      priv->func = (gpointer) class_init;
+      JSValueProtect (ctx, class_init);
+    }
+
 
   constructor_ref = JSObjectMake (ctx, gobject_constructor_class,
 				  (gpointer) 0);
   JSValueProtect (ctx, constructor_ref);
 
-  type_info.class_data = constructor_ref;
+  priv->constructor = constructor_ref;
+
+  JSValueProtect (ctx, arguments[0]);
+  priv->definition = (JSObjectRef) arguments[0];
+
+  type_info.class_data = priv;
 
   new_type = g_type_register_static (parent_type, new_name, &type_info, 0);
   seed_gobject_get_class_for_gtype (ctx, new_type);
@@ -520,6 +580,14 @@ seed_gtype_constructor_invoked (JSContextRef ctx,
 			    "type", seed_value_from_int (ctx, new_type,
 							 exception));
 
+  if (!JSValueIsNull (ctx, instance_init) &&
+      JSValueIsObject (ctx, instance_init) &&
+      JSObjectIsFunction (ctx, (JSObjectRef) instance_init))
+    {
+      g_type_set_qdata (new_type, qiinit, (gpointer) instance_init);
+      JSValueProtect (ctx, instance_init);
+    }
+
   g_free (new_name);
   return constructor_ref;
 }
@@ -536,10 +604,9 @@ seed_param_getter_invoked (JSContextRef ctx,
 
   if (argumentCount != 1)
     {
-      gchar *mes = g_strdup_printf ("ParamSpec.get expected "
-				    "1 argument, got %Zd", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "ParamSpec.get expected "
+			   "1 argument, got %zd", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
@@ -570,10 +637,9 @@ seed_param_setter_invoked (JSContextRef ctx,
 
   if (argumentCount != 1)
     {
-      gchar *mes = g_strdup_printf ("ParamSpec.set expected "
-				    "1 argument, got %Zd", argumentCount);
-      seed_make_exception (ctx, exception, "ArgumentError", mes);
-      g_free (mes);
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "ParamSpec.set expected "
+			   "1 argument, got %zd", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
@@ -626,6 +692,8 @@ seed_gtype_init (SeedEngine * local_eng)
 
   qgetter = g_quark_from_static_string ("js-getter");
   qsetter = g_quark_from_static_string ("js-setter");
+  qiinit = g_quark_from_static_string("js-instance-init");
+  qcinit = g_quark_from_static_string("js-class-init");
 
   seed_define_gtype_functions (local_eng->context);
 }
