@@ -49,10 +49,10 @@ GHashTable *file_imports;
  *        native module and return the module object.
  *      - If it is a file and does not end in G_MODULE_SUFFIX, evaluate it as a
  *        JavaScript file in a NEW global context, and return the global object
- *        for that context. 
+ *        for that context.
  */
 
-/* 
+/*
 * Handle definition of toplevel functions in a namespace.
 * i.e. Gtk.main
 */
@@ -66,7 +66,7 @@ seed_gi_importer_is_init (GIFunctionInfo *info)
     }
   if (g_callable_info_get_n_args ((GICallableInfo *)info) != 2)
     return FALSE;
-  
+
   return TRUE;
 }
 
@@ -77,14 +77,14 @@ seed_gi_importer_handle_function (JSContextRef ctx,
 				  JSValueRef *exception)
 {
   if (!seed_gi_importer_is_init (info))
-    seed_gobject_define_property_from_function_info (ctx, 
+    seed_gobject_define_property_from_function_info (ctx,
 						     (GIFunctionInfo *) info,
 						     namespace_ref, FALSE);
   else
     {
       JSObjectRef init_method;
-      
-      init_method = JSObjectMake(ctx, gobject_init_method_class, 
+
+      init_method = JSObjectMake(ctx, gobject_init_method_class,
 				 g_base_info_ref ((GIBaseInfo *)info));
       seed_object_set_property (ctx, namespace_ref, "init", init_method);
     }
@@ -104,11 +104,11 @@ seed_gi_importer_handle_enum (JSContextRef ctx,
 {
   JSObjectRef enum_class;
   gint num_vals, j;
-  
+
   enum_class = JSObjectMake (ctx, 0, 0);
   num_vals = g_enum_info_get_n_values (info);
-  seed_object_set_property (ctx, namespace_ref, 
-			    g_base_info_get_name ((GIBaseInfo *)info), 
+  seed_object_set_property (ctx, namespace_ref,
+			    g_base_info_get_name ((GIBaseInfo *)info),
 			    enum_class);
 
   for (j = 0; j < num_vals; j++)
@@ -121,22 +121,22 @@ seed_gi_importer_handle_enum (JSContextRef ctx,
       gint name_len = strlen (name);
       gint j;
       JSValueRef value_ref;
-      
+
       value_ref = JSValueMakeNumber (ctx, value);
       JSValueProtect (ctx, (JSValueRef) value_ref);
-      
+
       for (j = 0; j < name_len; j++)
 	{
 	  if (name[j] == '-')
 	    name[j] = '_';
 	  name[j] = g_ascii_toupper (name[j]);
 	}
-      
+
       seed_object_set_property (ctx, enum_class, name, value_ref);
-      
+
       g_free (name);
       g_base_info_unref ((GIBaseInfo *) val);
-      
+
     }
 }
 
@@ -153,24 +153,24 @@ seed_gi_importer_handle_object (JSContextRef ctx,
 {
   GType type;
   JSClassRef class_ref;
-  
-  type = 
+
+  type =
     g_registered_type_info_get_g_type ((GIRegisteredTypeInfo *) info);
-  
+
   if (type != 0)
     {
       GIFunctionInfo *finfo;
       GIFunctionInfoFlags flags;
       JSObjectRef constructor_ref;
       guint i, n_methods;
-      
+
       class_ref = seed_gobject_get_class_for_gtype (ctx, type);
-      
+
       constructor_ref =
 	JSObjectMake (ctx,
-		      gobject_constructor_class, 
+		      gobject_constructor_class,
 		      (gpointer) type);
-		      
+
       seed_object_set_property (ctx, constructor_ref,
 				"type",
 				seed_value_from_long (ctx, type, exception));
@@ -190,7 +190,7 @@ seed_gi_importer_handle_object (JSContextRef ctx,
 		fname += 4;
 	      else if (!strcmp (fname, "new"))
 		fname = "c_new";
-	      
+
 	      seed_object_set_property (ctx,
 					constructor_ref,
 					fname, constructor);
@@ -207,7 +207,7 @@ seed_gi_importer_handle_object (JSContextRef ctx,
 	}
 
       seed_object_set_property (ctx, namespace_ref,
-				g_base_info_get_name ((GIBaseInfo *) info), 
+				g_base_info_get_name ((GIBaseInfo *) info),
 				constructor_ref);
       seed_object_set_property (ctx, constructor_ref,
 				"prototype",
@@ -229,31 +229,31 @@ seed_gi_importer_handle_struct (JSContextRef ctx,
   JSObjectRef proto;
   gint i, n_methods;
   GIFunctionInfo *finfo;
-  
+
   struct_ref =
     JSObjectMake (ctx, seed_struct_constructor_class, info);
-  
+
   n_methods = g_struct_info_get_n_methods (info);
-  
+
   for (i = 0; i < n_methods; i++)
     {
       GIFunctionInfoFlags flags;
       finfo = g_struct_info_get_method (info, i);
-      
+
       flags = g_function_info_get_flags (finfo);
-      
+
       if (flags & GI_FUNCTION_IS_CONSTRUCTOR)
 	{
 	  JSObjectRef constructor = JSObjectMake (ctx,
 						  gobject_named_constructor_class,
 						  finfo);
-	  const gchar *fname = 
+	  const gchar *fname =
 	    g_base_info_get_name ((GIBaseInfo *) finfo);
 	  if (g_str_has_prefix (fname, "new_"))
 	    fname += 4;
 	  else if (!strcmp (fname, "new"))
 	    fname = "c_new";
-	  
+
 	  seed_object_set_property (ctx, struct_ref, fname, constructor);
 	}
       else if (flags & GI_FUNCTION_IS_METHOD)
@@ -262,10 +262,10 @@ seed_gi_importer_handle_struct (JSContextRef ctx,
 	seed_gobject_define_property_from_function_info
 	  (ctx, finfo, struct_ref, FALSE);
     }
-  
+
   proto = seed_struct_prototype (ctx, (GIBaseInfo *)info);
   seed_object_set_property (ctx, struct_ref, "prototype", proto);
-  
+
   seed_object_set_property (ctx, namespace_ref, g_base_info_get_name ((GIBaseInfo *)info), struct_ref);
 }
 
@@ -279,29 +279,29 @@ seed_gi_importer_handle_union (JSContextRef ctx,
   JSObjectRef proto;
   gint i, n_methods;
   GIFunctionInfo *finfo;
-  
+
   union_ref =
     JSObjectMake (ctx, seed_struct_constructor_class, info);
-  
+
   n_methods = g_union_info_get_n_methods (info);
-  
+
   for (i = 0; i < n_methods; i++)
     {
       GIFunctionInfoFlags flags;
       finfo = g_union_info_get_method (info, i);
-      
+
       flags = g_function_info_get_flags (finfo);
-      
+
       if (flags & GI_FUNCTION_IS_METHOD)
 	g_base_info_unref ((GIBaseInfo *) finfo);
       else
 	seed_gobject_define_property_from_function_info
 	  (ctx, finfo, union_ref, FALSE);
     }
-  
+
   proto = seed_union_prototype (ctx, (GIBaseInfo *)info);
   seed_object_set_property (ctx, union_ref, "prototype", proto);
-  
+
   seed_object_set_property (ctx, namespace_ref, g_base_info_get_name ((GIBaseInfo *)info), union_ref);
 }
 
@@ -311,7 +311,7 @@ seed_gi_importer_handle_callback (JSContextRef ctx,
 				  GICallbackInfo *info,
 				  JSValueRef *exception)
 {
-  JSObjectRef callback_ref = JSObjectMake (ctx, 
+  JSObjectRef callback_ref = JSObjectMake (ctx,
 					   seed_callback_class,
 					   info);
   seed_object_set_property (ctx, namespace_ref,
@@ -319,7 +319,7 @@ seed_gi_importer_handle_callback (JSContextRef ctx,
 			    (JSValueRef) callback_ref);
 }
 
-/* 
+/*
  * Define constants toplevel. Uses the casing as in the typelib
  */
 static void
@@ -332,7 +332,7 @@ seed_gi_importer_handle_constant (JSContextRef ctx,
   GITypeInfo *constant_type =
     g_constant_info_get_type (info);
   JSValueRef constant_value;
-  
+
   g_constant_info_get_value (info, &argument);
   constant_value =
     seed_gi_argument_make_js (ctx, &argument,
@@ -340,7 +340,7 @@ seed_gi_importer_handle_constant (JSContextRef ctx,
   seed_object_set_property (ctx, namespace_ref,
 			    g_base_info_get_name ((GIBaseInfo *) info),
 			    constant_value);
-  
+
   g_base_info_unref ((GIBaseInfo *) constant_type);
 }
 
@@ -351,12 +351,12 @@ seed_gi_importer_get_version (JSContextRef ctx,
 {
   JSValueRef version_ref;
   gchar *version = NULL;
-  
+
   version_ref = seed_object_get_property (ctx, gi_importer_versions, namespace);
   if (!JSValueIsUndefined(ctx, version_ref))
     version = seed_value_to_string (ctx, version_ref, exception);
-  
-  return version;  
+
+  return version;
 }
 
 static JSObjectRef
@@ -371,14 +371,14 @@ seed_gi_importer_do_namespace (JSContextRef ctx,
   gchar *version;
   gchar *jsextension;
   JSStringRef extension_script;
-  
+
   if ((namespace_ref = g_hash_table_lookup (gi_imports, namespace)))
     {
       SEED_NOTE (IMPORTER, "Using existing namespace ref (%p) for %s",
 		 namespace_ref, namespace);
       return namespace_ref;
     }
-  
+
   version = seed_gi_importer_get_version (ctx, namespace, exception);
   if (!g_irepository_require (NULL, namespace,
 			      version, 0, &e))
@@ -388,22 +388,22 @@ seed_gi_importer_do_namespace (JSContextRef ctx,
       return NULL;
     }
   g_free (version);
-  
+
   n = g_irepository_get_n_infos (NULL, namespace);
-  
+
   namespace_ref = JSObjectMake (ctx, NULL, NULL);
   SEED_NOTE (IMPORTER, "Constructing namespace ref (%p) for %s",
 	     namespace_ref, namespace);
 
   JSValueProtect (ctx, namespace_ref);
-  
+
   for (i = 0; i < n; i++)
     {
       GIInfoType info_type;
 
       info = g_irepository_get_info (NULL, namespace, i);
       info_type = g_base_info_get_type (info);
-      
+
       switch (info_type)
 	{
 	case GI_INFO_TYPE_FUNCTION:
@@ -427,15 +427,15 @@ seed_gi_importer_do_namespace (JSContextRef ctx,
 	  break;
 	case GI_INFO_TYPE_CONSTANT:
 	  seed_gi_importer_handle_constant (ctx, namespace_ref, (GIConstantInfo *) info, exception);
-	  break;	  
+	  break;
 	default:
 	  break;
 	}
       g_base_info_unref (info);
     }
-  
+
   g_hash_table_insert (gi_imports, g_strdup(namespace), namespace_ref);
-  
+
   jsextension = g_strdup_printf ("imports.extensions.%s",
 				 namespace);
   extension_script = JSStringCreateWithUTF8CString (jsextension);
@@ -443,27 +443,27 @@ seed_gi_importer_do_namespace (JSContextRef ctx,
   JSStringRelease (extension_script);
   g_free (jsextension);
 
-  
+
   return namespace_ref;
-  
-} 
+
+}
 
 static JSValueRef
 seed_gi_importer_get_property (JSContextRef ctx,
 			       JSObjectRef object,
-			       JSStringRef property_name, 
+			       JSStringRef property_name,
 			       JSValueRef *exception)
 {
   JSObjectRef ret;
   guint len;
   gchar *prop;
-  
+
   len = JSStringGetMaximumUTF8CStringSize (property_name);
   prop = g_alloca (len * sizeof (gchar));
   JSStringGetUTF8CString (property_name, prop, len);
-  
+
   SEED_NOTE (IMPORTER, "seed_gi_importer_get_property with %s", prop);
-  
+
   if (!strcmp(prop, "versions"))
     return gi_importer_versions;
   // Nasty hack
@@ -477,20 +477,20 @@ seed_gi_importer_get_property (JSContextRef ctx,
   SEED_NOTE (IMPORTER, "Result (%p) from attempting to import %s: %s",
 	     ret, prop, seed_value_to_string (ctx, ret, exception));
 
-  return ret;  
+  return ret;
 }
 
 static void
 seed_importer_free_search_path (GSList *path)
 {
   GSList *walk = path;
-  
+
   while (walk)
     {
       g_free (walk->data);
       walk = walk->next;
     }
-  
+
   g_slist_free (path);
 }
 
@@ -502,28 +502,28 @@ seed_importer_get_search_path (JSContextRef ctx,
   GSList *path = NULL;
   JSValueRef search_path_ref, length_ref;
   guint length, i;
-  
+
   search_path_ref = seed_object_get_property (ctx, importer, "searchPath");
   if (!JSValueIsObject(ctx, search_path_ref))
     {
       seed_make_exception (ctx, exception, "ArgumentError", "Importer searchPath object is not an array");
       return NULL;
     }
-  
+
   length_ref = seed_object_get_property (ctx, (JSObjectRef) search_path_ref, "length");
   length = seed_value_to_uint (ctx, length_ref, exception);
-  
+
   for (i = 0; i < length; i++)
     {
       JSValueRef entry_ref;
       gchar *entry;
-      
+
       entry_ref = JSObjectGetPropertyAtIndex (ctx, (JSObjectRef) search_path_ref, i, exception);
       entry = seed_value_to_string (ctx, entry_ref, exception);
-      
+
       path = g_slist_append (path, entry);
     }
-  
+
   return path;
 }
 
@@ -538,7 +538,7 @@ seed_importer_handle_native_module (JSContextRef ctx,
   JSObjectRef module_obj;
   SeedModuleInitCallback init;
   gchar *file_path = g_strconcat (dir, "/", file, NULL);
-  
+
   SEED_NOTE (IMPORTER, "Trying native module: %s", file_path);
 
   if ((module_obj = g_hash_table_lookup (file_imports, file_path)))
@@ -546,9 +546,9 @@ seed_importer_handle_native_module (JSContextRef ctx,
       g_free (file_path);
       return module_obj;
     }
-  
+
   module = g_module_open (file_path, 0);
-  
+
   if (!module)
     {
       // Could be a better exception
@@ -557,16 +557,16 @@ seed_importer_handle_native_module (JSContextRef ctx,
 			   file_path,
 			   g_module_error());
       g_free (file_path);
-      
+
       return NULL;
     }
   g_module_symbol (module, "seed_module_init", (gpointer *) &init);
   module_obj = (*init) (eng);
   g_hash_table_insert (file_imports, file_path, module_obj);
   SEED_NOTE (IMPORTER, "Loaded native module");
-  
+
   g_free (file_path);
-      
+
   return module_obj;
 }
 
@@ -575,11 +575,11 @@ seed_importer_canonicalize_path (gchar *path)
 {
   GFile *file;
   gchar *absolute_path;
-  
+
   file = g_file_new_for_path (path);
   absolute_path = g_file_get_path (file);
   g_object_unref (file);
-  
+
   return absolute_path;
 }
 
@@ -593,11 +593,11 @@ seed_importer_handle_file (JSContextRef ctx,
   JSObjectRef global, c_global;
   JSStringRef file_contents, file_name;
   gchar *contents, *walk, *file_path, *canonical;
-  
+
   file_path = g_strconcat (dir, "/", file, NULL);
   canonical = seed_importer_canonicalize_path (file_path);
   SEED_NOTE (IMPORTER, "Trying to import file: %s", file_path);
-  
+
   if ((global = g_hash_table_lookup (file_imports, canonical)))
     {
       SEED_NOTE (IMPORTER, "Using existing global");
@@ -616,7 +616,7 @@ seed_importer_handle_file (JSContextRef ctx,
 	}
       return NULL;
     }
-  
+
   g_file_get_contents (file_path, &contents, 0, NULL);
   walk = contents;
   if (*walk == '#')
@@ -630,29 +630,29 @@ seed_importer_handle_file (JSContextRef ctx,
 
   file_contents = JSStringCreateWithUTF8CString (walk);
   file_name = JSStringCreateWithUTF8CString (file);
-  
+
   nctx = JSGlobalContextCreateInGroup (context_group, 0);
   seed_prepare_global_context (nctx);
-  
+
   global = JSContextGetGlobalObject (nctx);
   c_global = JSContextGetGlobalObject (ctx);
   JSValueProtect (eng->context, global);
-  
+
   g_hash_table_insert (file_imports, canonical, global);
   g_free (file_path);
 
   JSEvaluateScript (nctx, file_contents, NULL, file_name, 0, exception);
 
   // Does leak...but it's a debug statement.
-  SEED_NOTE (IMPORTER, "Evaluated file, exception: %s", 
+  SEED_NOTE (IMPORTER, "Evaluated file, exception: %s",
 	     *exception ? seed_exception_to_string (ctx, *exception) : "(null)");
-  
+
   JSGlobalContextRelease ((JSGlobalContextRef) nctx);
-  
+
   JSStringRelease (file_contents);
   JSStringRelease (file_name);
   g_free (walk);
-  
+
   return global;
 }
 
@@ -662,10 +662,10 @@ seed_importer_search (JSContextRef ctx,
 		      JSValueRef *exception)
 {
   GSList *path, *walk;
-  gchar *prop_as_lib = g_strconcat ("lib", prop, ".", G_MODULE_SUFFIX, NULL);
-  
+  gchar *prop_as_lib = g_strconcat ("libseed_", prop, ".", G_MODULE_SUFFIX, NULL);
+
   path = seed_importer_get_search_path (ctx, exception);
-  
+
   walk = path;
   while (walk)
     {
@@ -677,7 +677,7 @@ seed_importer_search (JSContextRef ctx,
       if (e)
 	{
 	  g_error_free (e);
-	  
+
 	  walk = walk->next;
 	  continue;
 	}
@@ -694,7 +694,7 @@ seed_importer_search (JSContextRef ctx,
 	  if (!strcmp (mentry, prop))
 	    {
 	      JSObjectRef ret;
-	      
+
 	      ret = seed_importer_handle_file (ctx, walk->data, entry, exception);
 
 	      g_dir_close (dir);
@@ -707,7 +707,7 @@ seed_importer_search (JSContextRef ctx,
 	  else if (!strcmp(entry, prop_as_lib))
 	    {
 	      JSObjectRef ret;
-	      
+
 	      ret = seed_importer_handle_native_module (ctx, walk->data, entry, exception);
 	      g_dir_close (dir);
 	      g_free (mentry);
@@ -716,14 +716,14 @@ seed_importer_search (JSContextRef ctx,
 
 	      return ret;
 	    }
-	  
+
 	  g_free (mentry);
 	}
       g_dir_close (dir);
-      
+
       walk = walk->next;
     }
-  
+
   seed_importer_free_search_path (path);
   g_free (prop_as_lib);
   return NULL;
@@ -732,33 +732,33 @@ seed_importer_search (JSContextRef ctx,
 static JSValueRef
 seed_importer_get_property (JSContextRef ctx,
 			    JSObjectRef object,
-			    JSStringRef property_name, 
+			    JSStringRef property_name,
 			    JSValueRef *exception)
 {
   JSValueRef ret;
   guint len;
   gchar *prop;
-  
+
   len = JSStringGetMaximumUTF8CStringSize (property_name);
   prop = g_alloca (len * sizeof (gchar));
   JSStringGetUTF8CString (property_name, prop, len);
-  
+
   if (!strcmp (prop, "gi"))
     return gi_importer;
   if (!strcmp (prop, "searchPath"))
     return NULL;
   if (!strcmp (prop, "toString")) // HACK
     return NULL;
-  
+
   ret = seed_importer_search (ctx, prop, exception);
-  
+
   return ret;
 }
 
 static JSValueRef
 seed_importer_dir_get_property (JSContextRef ctx,
 				JSObjectRef object,
-				JSStringRef property_name, 
+				JSStringRef property_name,
 				JSValueRef *exception)
 {
   GError *e = NULL;
@@ -767,27 +767,27 @@ seed_importer_dir_get_property (JSContextRef ctx,
   const gchar *entry;
   gchar *dir_path, *prop;
 
-  
+
   dir_path = JSObjectGetPrivate (object);
-  
+
   len = JSStringGetMaximumUTF8CStringSize (property_name);
   prop = g_alloca (len * sizeof (gchar));
   JSStringGetUTF8CString (property_name, prop, len);
-  
+
   // TODO: GError
   dir = g_dir_open (dir_path, 0, &e);
   if (e)
     {
       seed_make_exception_from_gerror (ctx, exception, e);
       g_error_free (e);
-      
+
       return NULL;
     }
   while ((entry = g_dir_read_name (dir)))
     {
       gchar *mentry = g_strdup (entry);
       guint i;
-      
+
       for (i = 0; i < strlen (mentry); i++)
 	{
 	  if (mentry[i] == '.')
@@ -797,17 +797,17 @@ seed_importer_dir_get_property (JSContextRef ctx,
       if (!strcmp (mentry, prop))
 	{
 	  JSObjectRef ret;
-	  
+
 	  ret = seed_importer_handle_file (ctx, dir_path, entry, exception);
 	  g_dir_close (dir);
 	  g_free (mentry);
-	  
+
 	  return ret;
 	}
       g_free (mentry);
     }
   g_dir_close (dir);
-  
+
   return NULL;
 }
 
@@ -837,7 +837,7 @@ seed_importer_dir_enumerate_properties (JSContextRef ctx,
   GError *e = NULL;
   gchar *path = JSObjectGetPrivate (object);
 
-  
+
   dir = g_dir_open (path, 0, &e);
   if (e)
     {
@@ -846,11 +846,11 @@ seed_importer_dir_enumerate_properties (JSContextRef ctx,
       // Not much we can do here.
       return;
     }
-  
+
   while ((entry = g_dir_read_name (dir)))
     {
       JSStringRef jname;
-      
+
       jname = JSStringCreateWithUTF8CString (entry);
       JSPropertyNameAccumulatorAddName (propertyNames, jname);
       JSStringRelease (jname);
@@ -873,7 +873,7 @@ seed_importer_construct_dir (JSContextRef ctx,
       return (JSObjectRef)JSValueMakeUndefined (ctx);
     }
   path = seed_value_to_string (ctx, arguments[0], exception);
-  
+
   if (!g_file_test (path, G_FILE_TEST_IS_DIR))
     {
       seed_make_exception (ctx, exception, "ArgumentError",
@@ -881,29 +881,29 @@ seed_importer_construct_dir (JSContextRef ctx,
       g_free (path);
       return (JSObjectRef)JSValueMakeUndefined (ctx);
     }
-  
+
   return JSObjectMake (ctx, importer_dir_class, path);
 }
 
-void 
+void
 seed_importer_set_search_path(JSContextRef ctx,
 			      gchar **search_path)
 {
   JSObjectRef imports, array;
   JSValueRef *array_elem;
   guint length = g_strv_length (search_path), i;
-  
+
   array_elem = g_alloca (length * sizeof (array_elem));
   imports = (JSObjectRef) seed_object_get_property (ctx, JSContextGetGlobalObject (ctx), "imports");
-  
+
   for (i = 0; i < length; i++)
     {
       array_elem[i] = seed_value_from_string (ctx, search_path[i], NULL);
     }
-  
+
   array = JSObjectMakeArray (ctx, length, array_elem, NULL);
-  seed_object_set_property (ctx, imports, "searchPath", array);  
-  
+  seed_object_set_property (ctx, imports, "searchPath", array);
+
 }
 
 JSClassDefinition importer_class_def = {
@@ -973,23 +973,23 @@ void seed_initialize_importer(JSContextRef ctx,
 
   importer_class = JSClassCreate (&importer_class_def);
   importer = JSObjectMake (ctx, importer_class, NULL);
-  
+
   gi_importer_class = JSClassCreate (&gi_importer_class_def);
   gi_importer = JSObjectMake (ctx, gi_importer_class, NULL);
   gi_importer_versions = JSObjectMake (ctx, NULL, NULL);
-  
+
   JSValueProtect (ctx, gi_importer);
   JSValueProtect (ctx, gi_importer_versions);
-  
+
   importer_dir_class = JSClassCreate (&importer_dir_class_def);
-  
+
   gi_imports = g_hash_table_new (g_str_hash, g_str_equal);
   file_imports = g_hash_table_new (g_str_hash, g_str_equal);
-  
+
   /* Passing nonnull for class requires a webkit fix that most people wont have yet. It also has minimal benefit */
   //  dir_constructor = JSObjectMakeConstructor (ctx, importer_dir_class, seed_importer_construct_dir);
   dir_constructor = JSObjectMakeConstructor (ctx, NULL, seed_importer_construct_dir);
   seed_object_set_property (ctx, importer, "Directory", dir_constructor);
-					     
+
   seed_object_set_property (ctx, global, "imports", importer);
 }
